@@ -6,7 +6,7 @@ BEGIN {
   $Path::IsDev::Heuristic::AUTHORITY = 'cpan:KENTNL';
 }
 {
-  $Path::IsDev::Heuristic::VERSION = '0.3.3';
+  $Path::IsDev::Heuristic::VERSION = '0.4.0';
 }
 
 # ABSTRACT: Heuristic Base class
@@ -15,6 +15,7 @@ BEGIN {
 sub _path    { require Path::Tiny;   goto &Path::Tiny::path }
 sub _croak   { require Carp;         goto &Carp::croak }
 sub _blessed { require Scalar::Util; goto &Scalar::Util::blessed }
+sub _debug   { require Path::IsDev;  goto &Path::IsDev::debug }
 
 
 sub name {
@@ -32,6 +33,7 @@ sub _file_matches {
     my $stat = $root->child($file);
     next unless -e $stat;
     next unless -f $stat;
+    _debug("$stat exists for $self");
     return 1;
   }
   return;
@@ -45,6 +47,7 @@ sub _dir_matches {
     my $stat = $root->child($file);
     next unless -e $stat;
     next unless -d $stat;
+    _debug( "$stat exists for" . $self->name );
     return 1;
   }
   return;
@@ -79,7 +82,7 @@ Path::IsDev::Heuristic - Heuristic Base class
 
 =head1 VERSION
 
-version 0.3.3
+version 0.4.0
 
 =head1 METHODS
 
